@@ -1,4 +1,4 @@
-task("hello") {
+tasks.register("hello") {
     doLast {
         ant.withGroovyBuilder {
             "echo"("message" to "hello from Ant")
